==> haskell-magic-1.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: magic
version: 1.1
id: magic-1.1-H5xWVL7XeF31EsRFq6Sz0e
key: magic-1.1-H5xWVL7XeF31EsRFq6Sz0e
license: BSD3
copyright: Copyright (c) 2005-2009 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Alpha
synopsis: Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.
category: Text
author: John Goerzen
exposed: True
indefinite: False
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types
hidden-modules: Magic.Utils Magic.TypesLL
abi: 1cae236cbc599b11cba8e6f9fd2c185a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/magic-1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/magic-1.1
hs-libraries: HSmagic-1.1-H5xWVL7XeF31EsRFq6Sz0e
extra-libraries:
    magic
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html: /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-magic-1.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: magic
version: 1.1
id: magic-1.1-F3eOg0g57IEA2dVEHkvXgd
key: magic-1.1-F3eOg0g57IEA2dVEHkvXgd
license: BSD-3-Clause
copyright: Copyright (c) 2005-2009 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Alpha
synopsis: Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.
category: Text
abi: bc76ef2b2685262d84f0b852cfdcf5b3
exposed: True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types
hidden-modules: Magic.Utils Magic.TypesLL
import-dirs: /usr/lib/ghc-8.4.2/site-local/magic-1.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/magic-1.1
hs-libraries: HSmagic-1.1-F3eOg0g57IEA2dVEHkvXgd
extra-libraries:
    magic
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html: /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
